========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/python-solumclient.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

Python bindings to the Solum API
================================

This is a client library for Solum built on the Solum API.

* Free software: Apache license
* Documentation: https://wiki.openstack.org/wiki/Solum

Installation
============

At the command line::

    $ pip install python-solumclient

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv python-solumclient
    $ pip install python-solumclient

Usage
========

To use python-solumclient in a project::

    import solumclient
